# Changelog

All notable changes to this project will be documented in this file.

## [0.1.6] - 2025-03-29

### Added
- Changes in examples/custom.py
- Changes in examples/testing_with_memfs.py
- Changes in examples/webapp.py
- Changes in pyproject.toml

## [0.1.5] - 2025-03-29

### Added
- Changes in examples/advanced.py
- Changes in examples/basic.py
- Changes in tests/__init__.py
- Changes in tests/test_api.py

## [0.1.4] - 2025-03-29

## [0.1.3] - 2025-03-29

### Added
- Changes in src/memfs/api.py
- Changes in src/memfs/cli.py

## [0.1.2] - 2025-03-29

### Added
- Changes in src/memfs/__init__.py
- Changes in src/memfs/_version.py
- Changes in src/memfs/memfs.py
- Changes in tests/test_memfs.py

## [0.1.1] - 2025-03-29

### Added
- Changes in CNAME
- Changes in changelog.py
- Changes in git.sh
- Changes in publish.sh
- Changes in requirements.txt
- Changes in setup.cfg
- Changes in setup.py
- Changes in upgrade.sh
- Changes in version.sh

### Changed
- Changes in .gitignore

